# home$het/msetup/msetup.cl
# Package for setting up the MOS slitlet unit

# Created: 2002-Jan-31 by J. Tufts
# Last Modified: 2002-Nov-19 by J. Tufts
# Version 1.2.2

# Revision History:
# v.1.2.2 2002-Nov-19 (JRT)
#  - fixed garbage bug in makemos
#  - fixed cfg filename autogeneration bug
# v.1.2.1 2002-Oct-07 (JRT)
#  - corrected optical center distortion coordinates
#  - Added EKM's README.astrometry
#  - Added NGC7790 to parot
#  - Fixed errors in README
# v.1.2.0 2002-Jul-16 (JRT)
#  - corrected issue of existing msetup-1.0.0 package. Identical to 0.1.4
# v.0.1.4 2002-Jun-14 (JRT)
#  - Updated program version numbers in comments
# v.0.1.3 2002-Jun-10 (JRT)
#  - removed version numbers from task lines at bottom
# v.0.1.2 2002-Jun-5 by J. Tufts
#  - Added mmoscfg task which just generates a configuration file
#  - changed shm to sce since it is the center position, this reflects the
#    new mos baffle where slitlets@home is slitlets behind baffle, and slitlets
#    at 0 mm puts them all in the center lined up (~col 276.0)
# v.0.1.1 2002-Jun-03 by J. Tufts
#  - Development revision (odd minor number)

# Release Notes:
#  - This version includes: msetup (1.2.1), modmos (0.5.1), makemos (5.0.1),
#                           mfinder (0.1.1), mmoscfg(0.0.2), parot (0.1.3), 
#                           cfgcomp (0.0.2), lrsart  (0.0.3)

# USAGE:
#  - install all scripts in your iraf home directory under het/msetup/
#    if you install elsewhere change the "set het" and "set msetscr" lines below
#  - create a link msetup.cl -> msetup-1.2.1.cl if one is not created
#  - define the package with: task msetup = "home$het/msetup/msetup.cl"

# To Do:
#  - Modify scripts so ocent is in LRS unbinned full frame coordinates
#    right now it is in binned amode coords

# Load required packages
stsdas
toolbox
imgtools
tables
ttools

# MOS reduction package
package msetup

set  het        = "home$het/"
set  msetscr    = "het$msetup/"

# Define stream variables
string *mlist3
string *mlist4

# Define critical HET/LRS parameters
real    pi         # Numerical value of pi
real	asppix     # Plate scale of LRS camera in 1x1 imaging mode
real	mmppix     # Plate scale of HET focal surface at LRS slit plane (1x1)
real    imdco1     # Distortion coefficient for LRS in 1x1 imaging mode
real    imdco2     # Distortion coefficient for LRS in 2x2 imaging mode
real    ocent[2]   # Optical center of LRS image field x:[1] y:[2]
real    aspmm      # Plate scale of HET in LRS image (derived)
real	pixpas     # 1/asppix (1x1) (derived)
real    pixpmm     # 1/mmppix (1x1) (derived)
real    mmpas      # 1/aspmm  (derived)
# Define coefficients and slitlet position information
real    xco0[13]   # Distortion coefficients (in binned pixels)
real    xco1[13]   # 
real    xco2[13]
real    xco3[13]  
real    sbt[13]    # Y position of BOTTOM of slitlet at center of field
real    stp[13]    # Y position of TOP of slitlet at center of field
real    sze[13]    # X Slitlet 0.000 mm position (all in unbinned pixels)
real    slcenp,slmaxp,slminp,slbafp

# Set critical HET/LRS parameters (correct as of 2002-Jun-3 JRT)
pi = 2.0*atan(1,0)        # 3.1416
asppix = 0.2323           # 0.2323     (arcsec/pix) Scales with binning
mmppix = 0.048738         # 0.048738   (mm/pix)     Scales with binning
imdco1 = -2.1e-8          # -2.1e-8    (unbinned dist. coef) ~binning^2
ocent[1] = 568.           # 568.       unbinned opt cent of distortion in x 
ocent[2] = 512.           # 512.       opt. cent. of dist. in y
# Set derived parameters  #
aspmm  = asppix / mmppix  # 4.76630    (as/mm HET plate sc.) Det. independent
pixpas = 1 / asppix       # 4.30478    (pix/as) Scales with 1/binning
pixpmm = 1 / mmppix       # 20.518     (pix/mm) Scales with 1/binning
mmpas  = 1 / aspmm        # 0.20981    (HET plate scale) Detector independent
imdco2 = 4 * imdco1       # -8.4e-8    binned distortion coefficient

# Set coefficients (Correct 2002-Jun-3 JRT)
xco0[1] =5.6352
xco0[2] =4.1933
xco0[3] =3.7817
xco0[4] =2.4756
xco0[5] =2.2474
xco0[6] =2.0022
xco0[7] =1.7146
xco0[8] =2.2808
xco0[9] =2.1757
xco0[10]=3.1783
xco0[11]=3.8440
xco0[12]=4.7270
xco0[13]=4.4894

xco1[1] =-0.025350
xco1[2] =-0.023805
xco1[3] =-0.022246
xco1[4] =-0.019984
xco1[5] =-0.016875
xco1[6] =-0.017819
xco1[7] =-0.017529
xco1[8] =-0.018329
xco1[9] =-0.018103
xco1[10]=-0.020142
xco1[11]=-0.021734
xco1[12]=-0.025168
xco1[13]=-0.018491

xco2[1] =4.1295E-5
xco2[2] =4.4224E-5
xco2[3] =4.1826E-5
xco2[4] =4.2662E-5
xco2[5] =3.4663E-5
xco2[6] =3.8150E-5
xco2[7] =3.9227E-5
xco2[8] =3.8739E-5
xco2[9] =3.8266E-5
xco2[10]=3.8693E-5
xco2[11]=3.9913E-5
xco2[12]=4.5280E-5
xco2[13]=2.9104E-5

xco3[1] =-2.4992E-8
xco3[2] =-2.6758E-8
xco3[3] =-2.5284E-8
xco3[4] =-2.6107E-8
xco3[5] =-2.0766E-8
xco3[6] =-2.2621E-8
xco3[7] =-2.3649E-8
xco3[8] =-2.3433E-8
xco3[9] =-2.2793E-8
xco3[10]=-2.2943E-8
xco3[11]=-2.3883E-8
xco3[12]=-2.7272E-8
xco3[13]=-1.8515E-8

# Set slitlet position information (Correct 2002-Jun-3 JRT)
# The derivative peaks represent the point of steepest decent on the edges of
#  the slitlet, and therefore can be taken to mean the true edge of the slit.
#  It is advised that objects be located within the flat derivitave region
#  in the center of the slit.
# In the stable region the slit/space ratio is 27.3 pix / 13.4 pix or 2.04:1
# In the unstable region the ratio is 34.05 pix / 6.7 pix or 5.06:1
# Positions generated from a derivative of a MOS flat (20020412)
# Slit       Derivative Peaks       Derivative stable
#  1           1.00 -  30.31          1 -  27
#  2          37.01 -  70.27         40 -  67 # No data, calc'd from average
#  3          76.97 - 111.03         80 - 108
#  4         118.29 - 153.32        121 - 148
#  5         159.24 - 193.17        162 - 189
#  6         200.46 - 234.42        203 - 231
#  7         240.72 - 274.97        244 - 272
#  8         281.58 - 315.04        284 - 311
#  9         322.38 - 356.44        325 - 352
# 10         362.93 - 397.78        366 - 394
# 11         405.18 - 438.50        408 - 435
# 12         445.58 - 479.20        448 - 474
# 13         484.77 - 512.00        487 - 510
# Note all positions are in 2x2 binned pixels (1536x512 oscan sub. full fm.)
# We have chosen to generate the mask in the derivative stable region rather
#  than between peaks. Although the separation between peaks represents the
#  actual physical slits, the overall throughput has degraded by a factor of
#  two. Though the slit length is significantly degraded (1.5" off each end),
#  it is now perfectly reasonable to locate an object at the end of the slit.
#  This is the mode in which we found most users operating, feel free to 
#  change values if you work differently.
sbt[1] =   1.00
sbt[2] =  40.00
sbt[3] =  80.00
sbt[4] = 121.00
sbt[5] = 162.00
sbt[6] = 203.00
sbt[7] = 244.00
sbt[8] = 284.00
sbt[9] = 325.00
sbt[10]= 366.00
sbt[11]= 408.00
sbt[12]= 448.00
sbt[13]= 487.00

stp[1] =  27.00
stp[2] =  67.00
stp[3] = 108.00
stp[4] = 148.00
stp[5] = 189.00
stp[6] = 231.00
stp[7] = 272.00
stp[8] = 311.00
stp[9] = 352.00
stp[10]= 394.00
stp[11]= 435.00
stp[12]= 474.00
stp[13]= 510.00

# Slit home is now located behind a special mos baffle so a slitlet can be 
# eliminated from an image. Thus home=baffle and is indicated by a - in the
# mos configuration file.
# NOTE: larger pixel values correspond to smaller physical distances in mm
#       i.e. mm ~ -1 * const * (pixel + sce) + little bit
slcenp  = 276.00   # Pixel position of slits when at center (0.000 mm)
                   # NOTE: This is only for display an l in makemos drives
                   #       slitlet to 0.000 mm not calculated from slcent.
slmaxp  = 449.90   # Upper limit in pixel space of MOS slitlet (~ -17.0 mm)
slminp  = 102.10   # Lower limit in pixel space of MOS slitlet (~ +17.0 mm)
slbafp  = 460.66   # Approximate position of home or slitlet behind baffle
                   # NOTE: This is only for display a - in makemos puts a
                   #       - in the config file, so it is lrs dependent.
                   # NOTE: This must be less than the max x dim of image
sze[1]  = 553.10   # Unbinned pixel positions of slitlets at 0.000 mm
sze[2]  = 552.94   # NOTE: These numbers are actually used to calculate the
sze[3]  = 552.65   #       MOS configuration
sze[4]  = 552.54
sze[5]  = 552.43
sze[6]  = 552.21
sze[7]  = 551.99
sze[8]  = 551.74
sze[9]  = 551.77
sze[10] = 551.68
sze[11] = 551.58
sze[12] = 551.51
sze[13] = 551.47

printf ("                ,-----------------------------------. \n")
printf ("                | HET LRS/MOS Slitlet Setup Package | \n")
printf ("                |        v.1.2.1 2002-Oct-07        | \n")
printf ("                `-----------------------------------' \n\n")

# MOS setup programs

task	modmos	= "msetscr$modmos.cl"   # Stretch & rot. orth. image
task	makemos	= "msetscr$makemos.cl"  # Generate MOS setup info
task	mfinder	= "msetscr$mfinder.cl"  # Generate MOS finder
task    mmoscfg = "msetscr$mmoscfg.cl"  # Generate MOS configuration file
task	parot	= "msetscr$parot.cl"    # Calculate PA of image
task	cfgcomp	= "msetscr$cfgcomp.cl"  # Compare 2 config files
task	lrsart	= "msetscr$lrsart.cl"   # Gen. artificial LRS image
#task	test	= "msetscr$test.cl"

clbye()
